@@ -1177,6 +1177,17 @@ RPB_FUNCTION_VOID_4(METHOD(set_field_values), Rcpp::XPtr<GPB::Message> message,
     }
 }
 
-#undef METHOD
+//#undef METHOD
+
+/**
+ * Return the TextFormat of message
+ * @param xp external pointer to the Message
+ */
+RPB_FUNCTION_1(std::string, METHOD(print_text_format),
+               Rcpp::XPtr<GPB::Message> message) {
+  std::string message_text;
+  GPB::TextFormat::PrintToString(*message, &message_text);
+  return message_text;
+}
 
 }
